==> knowledge-center-api-0.3.8-sources.jar: cn/yoofans/knowledge/center/api/dto/poster/ClockPosterSnapshotDto.java <==
package cn.yoofans.knowledge.center.api.dto.poster;

import java.io.Serializable;

/**
 * 打卡海报快照实体
 * @author zhanghuifeng
 * @date 2018/8/31下午5:28
 */
public class ClockPosterSnapshotDto implements Serializable {

    private static final long serialVersionUID = 6458330883308366804L;
    /**
     * 主键ID
     */
    private Long id;

    /**
     * 用户ID
     */
    private Long consumerId;

    /**
     * 书籍ID
     */
    private Long readBookId;

    /**
     * 课程标题
     */
    private String courseTitle;

    /**
     * 打卡海报背景图
     */
    private String clockImgUrl;

    /**
     * 学习天数
     */
    private Integer studyDays;

    /**
     * 金句
     */
    private String goldContent;

    /**
     * 已读课本数
     */
    private Integer studyBookCount;

    /**
     * 分享文案
     */
    private String shareContent;

    /**
     * 分享图片
     */
    private String shareImgUrl;

    /**
     * 二维码图片
     */
    private String readQrcodeImgUrl;

    /**
     * 用户头像
     */
    private String userImgUrl;

    /**
     * 期数id
     */
    private Long readStageId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getReadBookId() {
        return readBookId;
    }

    public void setReadBookId(Long readBookId) {
        this.readBookId = readBookId;
    }

    public String getCourseTitle() {
        return courseTitle;
    }

    public void setCourseTitle(String courseTitle) {
        this.courseTitle = courseTitle;
    }

    public String getClockImgUrl() {
        return clockImgUrl;
    }

    public void setClockImgUrl(String clockImgUrl) {
        this.clockImgUrl = clockImgUrl;
    }

    public Integer getStudyDays() {
        return studyDays;
    }

    public void setStudyDays(Integer studyDays) {
        this.studyDays = studyDays;
    }

    public String getGoldContent() {
        return goldContent;
    }

    public void setGoldContent(String goldContent) {
        this.goldContent = goldContent;
    }

    public Integer getStudyBookCount() {
        return studyBookCount;
    }

    public void setStudyBookCount(Integer studyBookCount) {
        this.studyBookCount = studyBookCount;
    }

    public String getShareContent() {
        return shareContent;
    }

    public void setShareContent(String shareContent) {
        this.shareContent = shareContent;
    }

    public String getShareImgUrl() {
        return shareImgUrl;
    }

    public void setShareImgUrl(String shareImgUrl) {
        this.shareImgUrl = shareImgUrl;
    }

    public String getReadQrcodeImgUrl() {
        return readQrcodeImgUrl;
    }

    public void setReadQrcodeImgUrl(String readQrcodeImgUrl) {
        this.readQrcodeImgUrl = readQrcodeImgUrl;
    }

    public String getUserImgUrl() {
        return userImgUrl;
    }

    public void setUserImgUrl(String userImgUrl) {
        this.userImgUrl = userImgUrl;
    }

    public Long getReadStageId() {
        return readStageId;
    }

    public void setReadStageId(Long readStageId) {
        this.readStageId = readStageId;
    }
}

==> knowledge-center-api-0.4.5-sources.jar: cn/yoofans/knowledge/center/api/dto/poster/ClockPosterSnapshotDto.java <==
package cn.yoofans.knowledge.center.api.dto.poster;

import java.io.Serializable;
import java.util.Date;

/**
 * 打卡海报快照实体
 * @author zhanghuifeng
 * @date 2018/8/31下午5:28
 */
public class ClockPosterSnapshotDto implements Serializable {

    private static final long serialVersionUID = 6458330883308366804L;
    /**
     * 主键ID
     */
    private Long id;

    /**
     * 用户ID
     */
    private Long consumerId;

    /**
     * 书籍ID
     */
    private Long readBookId;

    /**
     * 课程标题
     */
    private String courseTitle;

    /**
     * 打卡海报背景图
     */
    private String clockImgUrl;

    /**
     * 学习天数
     */
    private Integer studyDays;

    /**
     * 金句
     */
    private String goldContent;

    /**
     * 已读课本数
     */
    private Integer studyBookCount;

    /**
     * 分享文案
     */
    private String shareContent;

    /**
     * 分享图片
     */
    private String shareImgUrl;

    /**
     * 二维码图片
     */
    private String readQrcodeImgUrl;

    /**
     * 用户头像
     */
    private String userImgUrl;

    /**
     * 期数id
     */
    private Long readStageId;

    private String courseAuthor;

    /**
     * 书籍封面
     */
    private String readBookCoverUrl;

    /**
     * 共读同学数
     */
    private Integer studyPeopleCount;

    /**
     * 课程id
     */
    private Long courseId;

    private Date gmtCreate;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getReadBookId() {
        return readBookId;
    }

    public void setReadBookId(Long readBookId) {
        this.readBookId = readBookId;
    }

    public String getCourseTitle() {
        return courseTitle;
    }

    public void setCourseTitle(String courseTitle) {
        this.courseTitle = courseTitle;
    }

    public String getClockImgUrl() {
        return clockImgUrl;
    }

    public void setClockImgUrl(String clockImgUrl) {
        this.clockImgUrl = clockImgUrl;
    }

    public Integer getStudyDays() {
        return studyDays;
    }

    public void setStudyDays(Integer studyDays) {
        this.studyDays = studyDays;
    }

    public String getGoldContent() {
        return goldContent;
    }

    public void setGoldContent(String goldContent) {
        this.goldContent = goldContent;
    }

    public Integer getStudyBookCount() {
        return studyBookCount;
    }

    public void setStudyBookCount(Integer studyBookCount) {
        this.studyBookCount = studyBookCount;
    }

    public String getShareContent() {
        return shareContent;
    }

    public void setShareContent(String shareContent) {
        this.shareContent = shareContent;
    }

    public String getShareImgUrl() {
        return shareImgUrl;
    }

    public void setShareImgUrl(String shareImgUrl) {
        this.shareImgUrl = shareImgUrl;
    }

    public String getReadQrcodeImgUrl() {
        return readQrcodeImgUrl;
    }

    public void setReadQrcodeImgUrl(String readQrcodeImgUrl) {
        this.readQrcodeImgUrl = readQrcodeImgUrl;
    }

    public String getUserImgUrl() {
        return userImgUrl;
    }

    public void setUserImgUrl(String userImgUrl) {
        this.userImgUrl = userImgUrl;
    }

    public Long getReadStageId() {
        return readStageId;
    }

    public void setReadStageId(Long readStageId) {
        this.readStageId = readStageId;
    }

    public String getCourseAuthor() {
        return courseAuthor;
    }

    public void setCourseAuthor(String courseAuthor) {
        this.courseAuthor = courseAuthor;
    }

    public String getReadBookCoverUrl() {
        return readBookCoverUrl;
    }

    public void setReadBookCoverUrl(String readBookCoverUrl) {
        this.readBookCoverUrl = readBookCoverUrl;
    }

    public Integer getStudyPeopleCount() {
        return studyPeopleCount;
    }

    public void setStudyPeopleCount(Integer studyPeopleCount) {
        this.studyPeopleCount = studyPeopleCount;
    }

    public Long getCourseId() {
        return courseId;
    }

    public void setCourseId(Long courseId) {
        this.courseId = courseId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
}
